/*********************************************************************
 *
 *      Copyright (C) 2002-2003 Marko van Dooren
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     JSwat
 * MODULE:      JSwat Actions
 * FILE:        OpenSessionAction.java
 *
 * AUTHOR:      Marko van Dooren
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      MvD     03/10/02        Initial version
 *      nf      04/16/02        Changed completely
 *
 * $Id: OpenSessionAction.java 850 2003-02-08 21:20:53Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.action;

import com.bluemarsh.jswat.Session;
import com.bluemarsh.jswat.util.SessionSettings;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.util.prefs.BackingStoreException;
import javax.swing.DefaultListModel;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JOptionPane;
import javax.swing.JScrollPane;
import javax.swing.JTextField;

/**
 * Class OpenSessionAction allows the user to load a saved session.
 *
 * @author Marko van Dooren
 * @author Nathan Fiedler
 */
public class OpenSessionAction extends JSwatAction {

    /**
     * Creates a new OpenSessionAction object with the default action
     * command string of "openSession".
     */
    public OpenSessionAction() {
        super("openSession");
    } // OpenSessionAction

    /**
     * Performs the open action. This presents the user with a list
     * of available session names and loads the chosen one.
     *
     * @param  event  action event
     */
    public void actionPerformed(ActionEvent event) {
        // get main window that contains our invoker
        Frame topFrame = getFrame(event);
        Session session = getSession(event);

        // Create the list and the scroller.
        DefaultListModel model = new DefaultListModel();
        String[] names = null;
        try {
            names = SessionSettings.getAvailableSettings();
        } catch (BackingStoreException bse) {
            session.getStatusLog().writeStackTrace(bse);
            return;
        }
        for (int ii = 0; ii < names.length; ii++) {
            model.addElement(names[ii]);
        }
        JList nameList = new JList(model);
        nameList.setVisibleRowCount(5);

        Object dialogElements[] = {
            new JLabel(Bundle.getString("OpenSession.currentName") + ' '
                       + SessionSettings.currentSettings()),
            Bundle.getString("OpenSession.chooseFromList"),
            new JScrollPane(nameList),
            Bundle.getString("OpenSession.enterNewName"),
            new JTextField(30)
        };

        String newName = null;
        while (newName == null) {
            // Show dialog to get user input.
            int response = JOptionPane.showOptionDialog(
                topFrame, dialogElements,
                Bundle.getString("OpenSession.dialogTitle"),
                JOptionPane.OK_CANCEL_OPTION,
                JOptionPane.QUESTION_MESSAGE,
                null, null, null);
            if (response != JOptionPane.OK_OPTION) {
                // user cancelled
                return;
            }

            // Did the user enter a name or select from the list?
            int idx = nameList.getSelectedIndex();
            if (idx >= 0) {
                newName = (String) model.get(idx);
            } else {
                newName = ((JTextField) dialogElements[4]).getText();
            }
            if (newName == null || newName.length() == 0) {
                // Missing the name to open.
                displayError(event, Bundle.getString(
                    "OpenSession.mustSelectName"));
                newName = null;
            }
        }

        // Load the named session.
        SessionSettings.loadSettings(newName);
    } // actionPerformed
} // OpenSession
