/*********************************************************************
 *
 *      Copyright (C) 1999-2002 Nathan Fiedler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     JSwat
 * MODULE:      JSwat Commands
 * FILE:        printCommand.java
 *
 * AUTHOR:      Nathan Fiedler
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      nf      08/30/99        Initial version
 *      ts      02/09/01        Added support for arrays
 *      nf      02/10/01        Tidied up formatting and variables
 *      nf      05/04/01        Fixed bug 45
 *      nf      07/09/01        Corrected the absent info message.
 *      nf      08/29/01        Implemented RFE 208
 *      nf      10/07/01        Fixed bugs 255, 256
 *      nf      12/15/01        Handle null return from toString()
 *      nf      01/23/02        Fixed bug 280
 *      nf      03/07/02        Fixed bug 401
 *      nf      06/07/02        Replaced everything with Evaluator
 *
 * $Id: printCommand.java 731 2002-12-09 03:50:21Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.command;

import com.bluemarsh.jswat.ContextManager;
import com.bluemarsh.jswat.Log;
import com.bluemarsh.jswat.Session;
import com.bluemarsh.jswat.expr.EvaluationException;
import com.bluemarsh.jswat.expr.Evaluator;
import com.bluemarsh.jswat.util.VariableUtils;
import com.sun.jdi.*;

/**
 * Defines the class that handles the 'print' command.
 *
 * @author  Nathan Fiedler
 */
public class printCommand extends JSwatCommand {

    /**
     * Perform the 'print' command.
     *
     * @param  session  JSwat session on which to operate.
     * @param  args     Tokenized string of command arguments.
     * @param  out      Output to write messages to.
     */
    public void perform(Session session, CommandArguments args, Log out) {
        // Check for enough arguments.
        if (!args.hasMoreTokens()) {
            throw new MissingArgumentsException();
        }

        // Get the current thread.
        ContextManager ctxtman = (ContextManager)
            session.getManager(ContextManager.class);
        ThreadReference thread = ctxtman.getCurrentThread();
        int frame = ctxtman.getCurrentFrame();

        // We do our own parsing, thank you very much.
        args.returnAsIs(true);
        String expr = args.rest();
        Evaluator eval = new Evaluator(expr);
        try {
            Object o = eval.evaluate(thread, frame);
            String s;
            if (o instanceof Value) {
                Value v = (Value) o;
                s = VariableUtils.printValue(v, thread, "\n");
            } else {
                if (o == null) {
                    s = "null";
                } else {
                    s = o.toString();
                }
            }
            out.writeln(s);
        } catch (EvaluationException ee) {
            throw new CommandException(
                Bundle.getString("evalError") + ' ' + ee.getMessage(), ee);
        } catch (Exception e) {
            throw new CommandException(e.getMessage(), e);
        }
    } // perform
} // printCommand
