/*********************************************************************
 *
 *      Copyright (C) 2002 Nathan Fiedler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     JSwat
 * MODULE:      Expression
 * FILE:        BasicNode.java
 *
 * AUTHOR:      Nathan Fiedler
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      nf      06/01/02        Initial version
 *
 * $Id: BasicNode.java 662 2002-11-02 07:25:59Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.expr;

import com.bluemarsh.jswat.parser.java.node.Token;

/**
 * Class BasicNode forms the root of the node class hierarchy.
 *
 * @author  Nathan Fiedler
 */
class BasicNode implements Node {
    /** Lexical token. */
    protected Token nodeToken;
    /** Parent node. */
    protected ParentNode parentNode;

    /**
     * Constructs a BasicNode associated with the given token.
     *
     * @param  node  lexical token.
     */
    public BasicNode(Token node) {
        nodeToken = node;
    } // BasicNode

    /**
     * Returns the value of this node.
     *
     * @param  context  evaluation context.
     * @return  value.
     * @throws  EvaluationException
     *          if an error occurred during evaluation.
     */
    public Object eval(EvaluationContext context) throws EvaluationException {
        return null;
    } // eval

    /**
     * Returns the parent node.
     *
     * @return  parent node.
     */
    public ParentNode getParent() {
        return parentNode;
    } // getParent

    /**
     * Returns the token node.
     *
     * @return  token node.
     */
    public Token getToken() {
        return nodeToken;
    } // getToken

    /**
     * Sets the parent node of this node.
     *
     * @param  parent  new parent node.
     */
    public void setParent(ParentNode parent) {
        parentNode = parent;
    } // setParent
} // BasicNode
