/*********************************************************************
 *
 *      Copyright (C) 2002 Nathan Fiedler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     JSwat
 * MODULE:      Expression
 * FILE:        PlusUnaryOperatorNode.java
 *
 * AUTHOR:      Nathan Fiedler
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      nf      06/04/02        Initial version
 *
 * $Id: PlusUnaryOperatorNode.java 662 2002-11-02 07:25:59Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.expr;

import com.bluemarsh.jswat.parser.java.node.Token;

/**
 * Class PlusUnaryOperatorNode implements the plus unary operator (+).
 *
 * @author  Nathan Fiedler
 */
class PlusUnaryOperatorNode extends UnaryOperatorNode {

    /**
     * Constructs a PlusUnaryOperatorNode.
     *
     * @param  node  lexical token.
     */
    public PlusUnaryOperatorNode(Token node) {
        super(node);
    } // PlusUnaryOperatorNode

    /**
     * Returns the value of this node.
     *
     * @param  context  evaluation context.
     * @return  value.
     * @throws  EvaluationException
     *          if an error occurred during evaluation.
     */
    public Object eval(EvaluationContext context) throws EvaluationException {
        Node n1 = getChild(0);
        Object o1 = n1.eval(context);
        if (isNumber(o1)) {
            if (!isFloating(o1)) {
                // o1 is an integer value.
                long l1 = getLongValue(o1);
                return new Long(0 + l1);
            } else {
                // o1 is a floating point value.
                double d1 = getDoubleValue(o1);
                return new Double(0 + d1);
            }
        } else {
            throw new EvaluationException(
                Bundle.getString("errorNumericOperator"), getToken());
        }
    } // eval

    /**
     * Returns this operator's precedence value. The lower the value
     * the higher the precedence. The values are equivalent to those
     * described in the Java Language Reference book (2nd ed.), p 106.
     *
     * @return  precedence value.
     */
    public int precedence() {
        return 5;
    } // precedence
} // PlusUnaryOperatorNode
