/*********************************************************************
 *
 *      Copyright (C) 2003 Nathan Fiedler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     JSwat
 * MODULE:      Expression
 * FILE:        TypeCastOperatorNode.java
 *
 * AUTHOR:      Nathan Fiedler
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      nf      05/11/03        Initial version
 *
 * $Id: TypeCastOperatorNode.java 0 2003-05-22 04:55:52Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.expr;

import com.bluemarsh.jswat.parser.java.node.Token;

/**
 * Class TypeCastOperatorNode implements the type-cast operator.
 *
 * @author  Nathan Fiedler
 */
class TypeCastOperatorNode extends UnaryOperatorNode implements TypedNode {
    /** The JNI type signature of the cast. */
    protected String jniSignature;

    /**
     * Constructs a TypeCastOperatorNode.
     *
     * @param  node  lexical token.
     */
    public TypeCastOperatorNode(Token node) {
        super(node);
    } // TypeCastOperatorNode

    /**
     * Returns the value of this node as the desired type.
     *
     * @param  context  evaluation context.
     * @return  a value of the desired type.
     * @throws  EvaluationException
     *          if an error occurred during evaluation.
     */
    public Object eval(EvaluationContext context) throws EvaluationException {
        // Get the type of the cast.
        String type = type(context);
        // Value to be cast.
        Node n = getChild(1);
        Object value = n.eval(context);
        // Is the value of the type we are expecting?
//         if (value != null && !clazz.isInstance(value)) {
//             // Need to transform the value to the desired type.
//             // Can the value be converted to the desired type?
//             // XXX
//         }
        return value;
    } // eval

    /**
     * Returns this operator's precedence value. The lower the value the
     * higher the precedence. The values are equivalent to those
     * described in the Java Language Reference book (2nd ed.), p 106.
     *
     * @return  precedence value.
     */
    public int precedence() {
        return 5;
    } // precedence

    /**
     * Returns the signature of the type this node represents. If the
     * type is void, or otherwise unrecognizable, an exception is
     * thrown.
     *
     * @param  context  evaluation context.
     * @return  type signature.
     * @throws  EvaluationException
     *          if an error occurred during evaluation.
     */
    public String type(EvaluationContext context) throws EvaluationException {
        if (jniSignature == null) {
            // The desired type is our first child.
            IdentifierNode in = (IdentifierNode) getChild(0);
            jniSignature = Types.typeNameToJNI(in.getName());
        }
        return jniSignature;
    } // type
} // TypeCastOperatorNode
