/*********************************************************************
 *
 *      Copyright (C) 2001-2003 David Taylor
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     jEdit JSwat Plugin
 * MODULE:      JSwat Plugin
 * FILE:        JSwatOptionPane.java
 *
 * AUTHOR:      David Taylor
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      dt      08/17/01        Initial version
 *
 * $Id: JSwatOptionPane.java 868 2003-03-01 02:07:08Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.plugins.jedit;

import com.bluemarsh.jswat.action.PathBuilder;
import org.gjt.sp.jedit.AbstractOptionPane;
import org.gjt.sp.jedit.jEdit;
import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JTextField;

/**
 * Provides the interface for changing the plugin settings.
 *
 * @author  David Taylor
 */
public class JSwatOptionPane extends AbstractOptionPane
    implements ActionListener {
    /** Button to build classpath. */
    private JButton buildClasspath;
    /** Button to build sourcepath. */
    private JButton buildSourcepath;
    /** Show this dialog when starting VM. */
    private JCheckBox showDialog;
    /** Show the toolbar in the main panel. */
    private JCheckBox showToolbar;
    /** Start the VM suspended. */
    private JCheckBox startSuspended;
    /** Parameters to the application. */
    private JTextField appParams;
    /** Classpath field. */
    private JTextField classPath;
    /** Sourcepath field. */
    private JTextField sourcePath;
    /** Class name field. */
    private JTextField clazzName;
    /** Java executable name. */
    private JTextField javaExec;
    /** Location of Java Runtime Environment. */
    private JTextField javaHome;
    /** Options to debuggee VM. */
    private JTextField jvmOptions;

    /**
     * Constructs a JSwatOptionPane.
     */
    public JSwatOptionPane() {
        super(JSwatPlugin.NAME);
    } // JSwatOptionPane

    /**
     * A button has been pressed -- do something.
     *
     * @param  evt  action event.
     */
    public void actionPerformed(ActionEvent evt) {
        Object source = evt.getSource();
        Component parentComp = getTopLevelAncestor();

        if (source == buildClasspath) {
            PathBuilder pathBuilder = new PathBuilder(false);
            pathBuilder.setPath(classPath.getText());
            pathBuilder.setFileFilter(new PathBuilder.ClasspathFilter());
            pathBuilder.setMultiSelectionEnabled(true);
            int response = JOptionPane.showOptionDialog(
                parentComp, pathBuilder,
                // LOCALIZE
                "Build Classpath",
                JOptionPane.OK_CANCEL_OPTION,
                JOptionPane.QUESTION_MESSAGE,
                null, null, null);
            if (response == JOptionPane.OK_OPTION) {
                classPath.setText(pathBuilder.getPath());
            }

        } else if (source == buildSourcepath) {
            PathBuilder pathBuilder = new PathBuilder(false);
            pathBuilder.setPath(sourcePath.getText());
            pathBuilder.setFileFilter(new PathBuilder.SourcepathFilter());
            pathBuilder.setMultiSelectionEnabled(true);
            int response = JOptionPane.showOptionDialog(
                parentComp, pathBuilder,
                // LOCALIZE
                "Build Sourcepath",
                JOptionPane.OK_CANCEL_OPTION,
                JOptionPane.QUESTION_MESSAGE,
                null, null, null);
            if (response == JOptionPane.OK_OPTION) {
                sourcePath.setText(pathBuilder.getPath());
            }
        }
    } // actionPerformed

    /**
     * Initialize the option pane.
     */
    public void _init() {
        GridBagConstraints constraints = new GridBagConstraints();
        int gridy = 0;

        // Java home
        JLabel label = new JLabel(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "javahome.title"));
        constraints.anchor = GridBagConstraints.EAST;
        constraints.gridx = 0;
        constraints.gridy = gridy++;
        constraints.weightx = 0.0;
        constraints.fill = GridBagConstraints.NONE;
        add(label, constraints);

        javaHome = new JTextField(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "javahome"), 30);
        constraints.anchor = GridBagConstraints.WEST;
        constraints.gridx = 1;
        constraints.weightx = 1.0;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        add(javaHome, constraints);

        // Java executable
        label = new JLabel(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "javaexec.title"));
        constraints.anchor = GridBagConstraints.EAST;
        constraints.gridx = 0;
        constraints.gridy = gridy++;
        constraints.weightx = 0.0;
        constraints.fill = GridBagConstraints.NONE;
        add(label, constraints);

        javaExec = new JTextField(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "javaexec"), 30);
        constraints.anchor = GridBagConstraints.WEST;
        constraints.gridx = 1;
        constraints.weightx = 1.0;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        add(javaExec, constraints);

        // Java executable
        label = new JLabel(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "jvmoptions.title"));
        constraints.anchor = GridBagConstraints.EAST;
        constraints.gridx = 0;
        constraints.gridy = gridy++;
        constraints.weightx = 0.0;
        constraints.fill = GridBagConstraints.NONE;
        add(label, constraints);

        jvmOptions = new JTextField(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "jvmoptions"), 30);
        constraints.anchor = GridBagConstraints.WEST;
        constraints.gridx = 1;
        constraints.weightx = 1.0;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        add(jvmOptions, constraints);

        // Main class
        label = new JLabel(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "classname.title"));
        constraints.anchor = GridBagConstraints.EAST;
        constraints.gridx = 0;
        constraints.gridy = gridy++;
        constraints.weightx = 0.0;
        constraints.fill = GridBagConstraints.NONE;
        add(label, constraints);

        clazzName = new JTextField(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "classname"), 30);
        constraints.anchor = GridBagConstraints.WEST;
        constraints.gridx = 1;
        constraints.weightx = 1.0;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        add(clazzName, constraints);

        // Application params
        label = new JLabel(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "appparams.title"));
        constraints.anchor = GridBagConstraints.EAST;
        constraints.gridx = 0;
        constraints.gridy = gridy++;
        constraints.weightx = 0.0;
        constraints.fill = GridBagConstraints.NONE;
        add(label, constraints);

        appParams = new JTextField(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "appparams"), 30);
        constraints.anchor = GridBagConstraints.WEST;
        constraints.gridx = 1;
        constraints.weightx = 1.0;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        add(appParams, constraints);

        // Classpath
        label = new JLabel(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "classpath.title"));
        constraints.anchor = GridBagConstraints.EAST;
        constraints.gridx = 0;
        constraints.gridy = gridy++;
        constraints.weightx = 0.0;
        constraints.fill = GridBagConstraints.NONE;
        add(label, constraints);

        classPath = new JTextField(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "classpath"), 30);
        constraints.anchor = GridBagConstraints.WEST;
        constraints.gridx = 1;
        constraints.weightx = 1.0;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        add(classPath, constraints);

        // Classpath builder button
        constraints.anchor = GridBagConstraints.CENTER;
        constraints.gridx = 2;
        constraints.weightx = 0.0;
        constraints.weighty = 0.0;
        constraints.fill = GridBagConstraints.NONE;
        buildClasspath = new JButton("...");
        add(buildClasspath, constraints);

        // Source path
        label = new JLabel(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "sourcepath.title"));
        constraints.anchor = GridBagConstraints.EAST;
        constraints.gridx = 0;
        constraints.gridy = gridy++;
        constraints.weightx = 0.0;
        constraints.weighty = 0.0;
        constraints.fill = GridBagConstraints.NONE;
        add(label, constraints);

        sourcePath = new JTextField(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "sourcepath"), 30);
        constraints.anchor = GridBagConstraints.WEST;
        constraints.gridx = 1;
        constraints.weightx = 1.0;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        add(sourcePath, constraints);

        // Sourcepath builder button
        constraints.anchor = GridBagConstraints.CENTER;
        constraints.gridx = 2;
        constraints.weightx = 0.0;
        constraints.weighty = 0.0;
        constraints.fill = GridBagConstraints.NONE;
        buildSourcepath = new JButton("...");
        add(buildSourcepath, constraints);

        // Start suspended
        constraints.gridx = 1;
        constraints.gridy = gridy++;
        constraints.weightx = 0.0;
        constraints.fill = GridBagConstraints.NONE;
        startSuspended = new JCheckBox(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX
                              + "start-suspended.title"),
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX
                              + "start-suspended").equals("true"));
        add(startSuspended, constraints);

        // Show dialog
        constraints.gridy = gridy++;
        showDialog = new JCheckBox(
            jEdit.getProperty(JSwatPlugin.OPTION_PREFIX + "show-dialog.title"),
            jEdit.getProperty(
                JSwatPlugin.OPTION_PREFIX + "show-dialog").equals("true"));
        add(showDialog, constraints);

        buildClasspath.addActionListener(this);
        buildSourcepath.addActionListener(this);
    } // _init

    /**
     * Save the options.
     */
    public void _save() {
        jEdit.setProperty(JSwatPlugin.OPTION_PREFIX + "javahome",
            javaHome.getText());
        jEdit.setProperty(JSwatPlugin.OPTION_PREFIX + "javaexec",
            javaExec.getText());
        jEdit.setProperty(JSwatPlugin.OPTION_PREFIX + "jvmoptions",
            jvmOptions.getText());
        jEdit.setProperty(JSwatPlugin.OPTION_PREFIX + "classname",
            clazzName.getText());
        jEdit.setProperty(JSwatPlugin.OPTION_PREFIX + "appparams",
            appParams.getText());
        jEdit.setProperty(JSwatPlugin.OPTION_PREFIX + "classpath",
            classPath.getText());
        jEdit.setProperty(JSwatPlugin.OPTION_PREFIX + "sourcepath",
            sourcePath.getText());
        jEdit.setProperty(JSwatPlugin.OPTION_PREFIX + "start-suspended",
            String.valueOf(startSuspended.isSelected()));
        jEdit.setProperty(JSwatPlugin.OPTION_PREFIX + "show-dialog",
            String.valueOf(showDialog.isSelected()));
    } // _save
} // JSwatOptionPane
