/*********************************************************************
 *
 *      Copyright (C) 2002 Nathan Fiedler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     JSwat
 * MODULE:      Unit Tests
 * FILE:        EvaluatorTest.java
 *
 * AUTHOR:      Nathan Fiedler
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      nf      07/22/02        Initial version
 *
 * $Id: EvaluatorTest.java 706 2002-11-30 20:03:10Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.expr;

import junit.extensions.*;
import junit.framework.*;

/**
 * Tests the Evaluator class.
 */
public class EvaluatorTest extends TestCase {

    public EvaluatorTest(String name) {
        super(name);
    }

    public static Test suite() {
        return new TestSuite(EvaluatorTest.class);
    }

    public static void main(String[] args) {
        junit.textui.TestRunner.run(suite());
    }

    public void testEvaluatorBasic() {
        Evaluator eval = new Evaluator(null);
        try {

            // Supported operators:
            //
            // - (unary), + (unary), !, ~
            // *, /, %
            // +, -
            // <<, >>, >>>
            // <, >, <=, <=
            // ==, !=
            // &
            // ^
            // |
            // &&
            // ||

            Object result = eval.evaluate(null, 0);
            assertNull(result);

            eval = new Evaluator("");
            result = eval.evaluate(null, 0);
            assertNull(result);

            eval = new Evaluator("null");
            result = eval.evaluate(null, 0);
            assertNull(result);

            eval = new Evaluator("1 + 1");
            result = eval.evaluate(null, 0);
            assertEquals("2", result.toString());

            eval = new Evaluator("2 - 1");
            result = eval.evaluate(null, 0);
            assertEquals("1", result.toString());

            eval = new Evaluator("2 - -1");
            result = eval.evaluate(null, 0);
            assertEquals("3", result.toString());

            eval = new Evaluator("1 - 2");
            result = eval.evaluate(null, 0);
            assertEquals("-1", result.toString());

            eval = new Evaluator("1 - +2");
            result = eval.evaluate(null, 0);
            assertEquals("-1", result.toString());

            eval = new Evaluator("1 * 2");
            result = eval.evaluate(null, 0);
            assertEquals("2", result.toString());

            eval = new Evaluator("6 / 2");
            result = eval.evaluate(null, 0);
            assertEquals("3", result.toString());

            eval = new Evaluator("11 % 2");
            result = eval.evaluate(null, 0);
            assertEquals("1", result.toString());

            eval = new Evaluator("1 + 2 * 3");
            result = eval.evaluate(null, 0);
            assertEquals("7", result.toString());

            eval = new Evaluator("false");
            result = eval.evaluate(null, 0);
            assertEquals("false", result.toString());

            eval = new Evaluator("true");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("!true");
            result = eval.evaluate(null, 0);
            assertEquals("false", result.toString());

            eval = new Evaluator("\"abc\"");
            result = eval.evaluate(null, 0);
            assertEquals("abc", result.toString());

            eval = new Evaluator("128");
            result = eval.evaluate(null, 0);
            assertEquals("128", result.toString());

            eval = new Evaluator("~128");
            result = eval.evaluate(null, 0);
            assertEquals("127", result.toString());

            eval = new Evaluator("true == true");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("true == false");
            result = eval.evaluate(null, 0);
            assertEquals("false", result.toString());

            eval = new Evaluator("true != true");
            result = eval.evaluate(null, 0);
            assertEquals("false", result.toString());

            eval = new Evaluator("true != false");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("255 & 32");
            result = eval.evaluate(null, 0);
            assertEquals("32", result.toString());

            eval = new Evaluator("64 | 32");
            result = eval.evaluate(null, 0);
            assertEquals("96", result.toString());

            eval = new Evaluator("255 ^ 32");
            result = eval.evaluate(null, 0);
            assertEquals("223", result.toString());

            eval = new Evaluator("32 >> 4");
            result = eval.evaluate(null, 0);
            assertEquals("2", result.toString());

            eval = new Evaluator("32 > 4");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("4 > 32");
            result = eval.evaluate(null, 0);
            assertEquals("false", result.toString());

            eval = new Evaluator("32 < 4");
            result = eval.evaluate(null, 0);
            assertEquals("false", result.toString());

            eval = new Evaluator("4 < 32");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("4 <= 32");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("32 <= 32");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("32 >= 4");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("32 >= 32");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("0xF1234567 >>> 4");
            result = eval.evaluate(null, 0);
            assertEquals("252851286", result.toString());

            eval = new Evaluator("2 << 4");
            result = eval.evaluate(null, 0);
            assertEquals("32", result.toString());

            eval = new Evaluator("true || false");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("false || false");
            result = eval.evaluate(null, 0);
            assertEquals("false", result.toString());

            eval = new Evaluator("true && true");
            result = eval.evaluate(null, 0);
            assertEquals("true", result.toString());

            eval = new Evaluator("true && false");
            result = eval.evaluate(null, 0);
            assertEquals("false", result.toString());

        } catch (EvaluationException ee) {
            fail(ee.toString());
        }
    }

    public void testEvaluatorGroups() {
        Evaluator eval = new Evaluator("(1 + 2) * 3");
        try {
            Object result = eval.evaluate(null, 0);
            assertEquals("9", result.toString());

            eval = new Evaluator("(1) + (2) * (3)");
            result = eval.evaluate(null, 0);
            assertEquals("7", result.toString());

            eval = new Evaluator("((1 + (2 * 3)))");
            result = eval.evaluate(null, 0);
            assertEquals("7", result.toString());

            eval = new Evaluator("(((1)))");
            result = eval.evaluate(null, 0);
            assertEquals("1", result.toString());

        } catch (EvaluationException ee) {
            fail(ee.toString());
        }
    }

    public void testEvaluatorTypes() {
        Evaluator eval = new Evaluator("true");
        try {
            Object result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("!false");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("true || false");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("true && false");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("true == false");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("true != false");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("32 > 16");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("32 < 16");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("16 < 32");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("16 > 32");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("16 <= 32");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("16 >= 32");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Boolean);

            eval = new Evaluator("12345");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("123 + 45");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("123 - 45");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("123 * 45");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("123 / 45");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("123 % 45");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("255 & 32");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("255 ^ 32");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("64 | 32");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("32 >> 4");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("32 >>> 4");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("32 << 4");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("~128");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("-128");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

            eval = new Evaluator("+128");
            result = eval.evaluate(null, 0);
            assertTrue(result instanceof Number);

        } catch (EvaluationException ee) {
            fail(ee.toString());
        }
    }
}
