/*********************************************************************
 *
 *      Copyright (C) 2002 Nathan Fiedler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     JSwat
 * MODULE:      Unit Tests
 * FILE:        ClassUtilsTest.java
 *
 * AUTHOR:      Nathan Fiedler
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      nf      07/23/02        Initial version
 *
 * $Id: ClassUtilsTest.java 662 2002-11-02 07:25:59Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.util;

import com.bluemarsh.jswat.Defaults;
import java.util.prefs.Preferences;
import junit.extensions.*;
import junit.framework.*;

/**
 * Tests the ClassUtils class.
 */
public class ClassUtilsTest extends TestCase {

    public ClassUtilsTest(String name) {
        super(name);
    }

    public static Test suite() {
        return new TestSuite(ClassUtilsTest.class);
    }

    public static void main(String[] args) {
        junit.textui.TestRunner.run(suite());
    }

    public void testClassUtilsIsJavaIdentifier() {
        // boolean isJavaIdentifier(String s);
        assertTrue(!ClassUtils.isJavaIdentifier(null));
        assertTrue(!ClassUtils.isJavaIdentifier(""));
        assertTrue(ClassUtils.isJavaIdentifier("ident"));
        assertTrue(ClassUtils.isJavaIdentifier("_ident"));
        assertTrue(!ClassUtils.isJavaIdentifier("128_ident"));
        assertTrue(ClassUtils.isJavaIdentifier("ide_nt"));
    }

    public void testClassUtilsIsPrimitive() {
        // boolean isPrimitive(String s);
        assertTrue(!ClassUtils.isPrimitive(null));
        assertTrue(!ClassUtils.isPrimitive(""));
        assertTrue(!ClassUtils.isPrimitive("ident"));
        assertTrue(!ClassUtils.isPrimitive("12345"));
        assertTrue(ClassUtils.isPrimitive("boolean"));
        assertTrue(ClassUtils.isPrimitive("byte"));
        assertTrue(ClassUtils.isPrimitive("char"));
        assertTrue(ClassUtils.isPrimitive("short"));
        assertTrue(ClassUtils.isPrimitive("int"));
        assertTrue(ClassUtils.isPrimitive("float"));
        assertTrue(ClassUtils.isPrimitive("double"));
        assertTrue(ClassUtils.isPrimitive("long"));
    }

    public void testClassUtilsJustTheName() {
        // Save the old setting first, then change it to true.
        Preferences prefs = Preferences.userRoot().node(
            "com/bluemarsh/jswat/util");
        boolean old = prefs.getBoolean("shortClassNames",
                                       Defaults.SHORT_CLASS_NAMES);
        prefs.putBoolean("shortClassNames", true);

        // String justTheName(String cname);
        assertNull(ClassUtils.justTheName(null));
        assertEquals("", ClassUtils.justTheName(""));
        assertEquals("abc", ClassUtils.justTheName("abc"));
        assertEquals("abc", ClassUtils.justTheName("com.abc"));
        assertEquals("abc", ClassUtils.justTheName("com.package.abc"));

        // Restore the previous setting.
        prefs.putBoolean("shortClassNames", old);
    }
}
